@@ -2,7 +2,7 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-__all__ = ['compress_page']
+__all__ = ["compress_page"]
 
 
 from .middleware import CompressionMiddleware
